﻿import React, { useState, useCallback } from 'react';
// import AnimatedPlant from './components/AnimatedPlant'; // <-- Удалить или закомментировать
import CircularProgress from './components/CircularProgress'; // <-- Добавить импорт диаграммы
import WaterControls from './components/WaterControls';
import './App.css';

function App() {
    const [currentWater, setCurrentWater] = useState(0);
    const dailyGoal = 2000;

    const handleAddWater = useCallback((amount: number) => {
        if (!isNaN(amount) && amount > 0) {
            setCurrentWater((prevWater: number) => prevWater + amount);
        } else {
            console.warn("Попытка добавить некорректное количество воды:", amount);
        }
    }, []);

    // Рассчитываем процент выполнения цели
    const percentage = dailyGoal > 0 ? (currentWater / dailyGoal) * 100 : 0;

    // Можно добавить изменение цвета в зависимости от процента (опционально)
    let progressColor = '#e74c3c'; // Красный по умолчанию (низкий процент)
    if (percentage >= 100) {
        progressColor = '#2ecc71'; // Зеленый (цель достигнута)
    } else if (percentage >= 50) {
        progressColor = '#f39c12'; // Оранжевый (половина и больше)
    }


    return (
        <div className="App">
            <header className="App-header">
                <h1>АкваДруг</h1>
                <p>Твой помощник в гидратации!</p>
            </header>

            <main>
                {/* Отображаем круговую диаграмму вместо растения */}
                <CircularProgress
                    percentage={percentage}
                    size={200} /* Можете настроить размер */
                    strokeWidth={15} /* И толщину линии */
                    color={progressColor} /* Передаем рассчитанный цвет */
                    showText={true} /* Показываем проценты */
                />

                <div className="progress-info">
                    Выпито сегодня: <strong>{currentWater} мл</strong> / {dailyGoal} мл
                </div>

                <WaterControls onAddWater={handleAddWater} />
            </main>

            <footer className="App-footer">
                <p>Не забывай пить воду!</p>
            </footer>
        </div>
    );
}

export default App;