import React from 'react';
import './CircularProgress.css'; //   

interface CircularProgressProps {
    percentage: number;    //   ( 0  100)
    size?: number;        //   (  )
    strokeWidth?: number; //  
    color?: string;       //   
    showText?: boolean;   //       
}

const CircularProgress: React.FC<CircularProgressProps> = ({
    percentage,
    size = 180, //   
    strokeWidth = 12, //    
    color = '#3498db', //    ()
    showText = true,   //    
}) => {
    //    0  100
    const pct = Math.max(0, Math.min(100, percentage));

    //   SVG /
    const radius = (size - strokeWidth) / 2; //    
    const circumference = 2 * Math.PI * radius; //  
    //    ( ""   )
    const offset = circumference - (pct / 100) * circumference;

    //  
    const center = size / 2;

    return (
        <div className="circular-progress-container" style={{ width: size, height: size }}>
            <svg
                className="circular-progress-svg"
                width={size}
                height={size}
                viewBox={`0 0 ${size} ${size}`} // viewBox  
            >
                {/*   () */}
                <circle
                    className="progress-ring__background"
                    stroke="#e6e6e6" //  
                    strokeWidth={strokeWidth}
                    fill="transparent" //  
                    r={radius} // 
                    cx={center} //  X
                    cy={center} //  Y
                />
                {/*   () */}
                <circle
                    className="progress-ring__progress"
                    stroke={color} //  
                    strokeWidth={strokeWidth}
                    strokeDasharray={`${circumference} ${circumference}`} //  ""   
                    style={{ strokeDashoffset: offset }} //    
                    strokeLinecap="round" //   
                    fill="transparent"
                    r={radius}
                    cx={center}
                    cy={center}
                    //  ,  0%  
                    transform={`rotate(-90 ${center} ${center})`}
                />
                {/*      */}
                {showText && (
                    <text
                        className="progress-ring__text"
                        x="50%" //   X
                        y="50%" //   Y
                        dominantBaseline="middle" //    
                        textAnchor="middle" //    
                        fill={color} //    ,   
                    >
                        {`${Math.round(pct)}%`}
                    </text>
                )}
            </svg>
        </div>
    );
};

export default CircularProgress;